package com.cringe_studios.cringe_authenticator_library;

public abstract class OTP {
	//TOTP
	//HOTP
	
	protected String secret;
	protected OTPType type;
	protected OTPAlgorithm algorithm;
	protected int digits;
	protected long counter;
	protected long period;
	protected boolean checksum;
	
	protected OTP(OTPType nType, String nSecret, OTPAlgorithm nAlgorithm, int nDigits, long nCounter, long nPeriodInSeconds, boolean nChecksum) {
		this.secret = nSecret;
		type = nType;
		algorithm = nAlgorithm;
		digits = nDigits;
		counter = nCounter;
		period = nPeriodInSeconds;
		checksum = nChecksum;
	}
	
	//secret: required
	//algorithm: optional (default SHA1)
	//digits: optional (default 6)
	//OTPType: required
	//period: optional (default 30)
	//counter: required if hotp
	public static OTP createNewOTP(OTPType type, String secret, OTPAlgorithm algorithm, int digits, long counter, long periodInSeconds, boolean checksum) {
		return type.instance(secret, algorithm, digits, counter, periodInSeconds, checksum);
	}
	
	public abstract long getNextDueTime();
	
	public abstract String getPin();
	
	public String getSecret() {
		return this.secret;
	}
	
	public OTPType getOTPType() {
		return this.type;
	}
	
	public OTPAlgorithm getAlgorithm() {
		return algorithm;
	}
	
	public int getDigits() {
		return this.digits;
	}
	
	public long getCounter() {
		return this.counter;
	}
	
	public long getPeriod() {
		return this.period;
	}
	
	public boolean hasChecksum() {
		return checksum;
	}
}